<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Feu clic per tornar a l&apos;aplicació</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Neteja</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 elements</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Torneu-ho a intentar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publica un podcast al YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor/a</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tauler</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Estris</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fons</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Afegeix a la pàgina actual</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Afegeix a una pàgina nova</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Afegeix a la biblioteca</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pàgines</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Pàgina nova</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Canvia el fons</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refés</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Pàgina anterior</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Tecla de retrocedir pàgina</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pàgina següent</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Tecla d&apos;avançar pàgina</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Gestiona els documents</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Navegació web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Línia petita</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Línia mitjana</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Línia gran</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Esborrador</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Esborrador petit</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Esborrador mitjà</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Esborrador gran</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Color</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Cap endavant</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Torna a carregar</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Torna a carregar la pàgina actual</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Carrega la pàgina d&apos;inici</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Adreces d&apos;interès</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Mostra les adreces d&apos;interès</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Adreça d&apos;interès</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Afegeix una adreça d&apos;interès</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Mostra el tauler</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Esborra el contingut</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Visualitza les preferències</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Mostra la biblioteca</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra l&apos;escriptori</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Mostra l&apos;escriptori de l&apos;ordinador</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Maj+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Més gran</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Apropa</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Més petit</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Allunya</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Carpeta nova</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Crea una carpeta nova</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Document nou</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Crea un document nou</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importa un document</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exporta un document</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Obre al tauler</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Obre la pàgina al tauler</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplica el contingut seleccionat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Elimina el contingut seleccionat</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Afegeix al document de treball</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Afegeix el contingut seleccionat al document obert</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Afegeix contingut al document</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Canvia el nom del contingut</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eines</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Mostra les eines</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multipantalla</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Mida ampla (16:9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Utilitza la mida de document ampla (16:9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Mida normal (4:3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Utilitza la mida de document normal (4:3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Mida personalitzada</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Utilitza la mida de document personalitzada</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Atura la càrrega</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Atura la càrrega de la pàgina web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Adorm</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Adorm la presentació</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclat virtual</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Mostra el tecla virtual</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fons clar llis</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clar</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fons clar quadriculat</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fons fosc llis</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fons fosc quadriculat</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Enregistra la presentació en vídeo</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enregistra</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Inicia l&apos;enregistrament de la pantalla</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Esborra els elements</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Esborra tots els elements</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Esborra les anotacions</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Esborra totes les anotacions</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Esborra la pàgina</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Esborra tots els elements</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Anota al document</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Esborra l&apos;anotació</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Ressalta</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selector</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Selecciona i modifica objectes</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Mà</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Captura part de la pantalla</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Captura personalitzada</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Captura una finestra</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Incrusta contingut web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Captura contingut web incrustable</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Mostra la pantalla principal a la pantalla</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importa una simulació eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Comprova si hi ha actualitzacions</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Desplaça la pàgina</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Punter làser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Punter làser virtual</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Dibuixa línies</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Escriu text</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Afegeix l&apos;element a la pàgina actual</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Afegeix l&apos;element a una pàgina nova</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Afegeix l&apos;element a la biblioteca</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Crea una pàgina nova</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplica la pàgina</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplica la pàgina actual</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importa una pàgina</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importa una pàgina externa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posa en pausa</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Posa en pausa l&apos;enregistrament del podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Configuració del podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configura l&apos;enregistrament del podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Captura d&apos;objectes Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Captura un objecte Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Captura de contingut web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Captura d&apos;un contingut web</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Captura de finestra</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Mostra a la pantalla</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Surt de l&apos;OpenBoard</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Esborra totes les anotacions</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Amaga l&apos;OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Amaga l&apos;aplicació OpenBoard</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interactua amb els elements</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Esborra el fons</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Elimina el fons</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Cal autenticació</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticació del servidor intermediari</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Connecta al servidor intermediari</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Desa el nom d&apos;usuari i la contrasenya per a un ús futur</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID de l&apos;element = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Aquest contingut no està suportat pel format escollit.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Suprimeix la pàgina</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Esteu segur que voleu eliminar 1 pàgina del document seleccionat &apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Mida de la pàgina</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Hi ha disponible una actualització. Voleu visitar la web per descarregar-la?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>No hi ha cap actualització disponible</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Hi ha una actualització disponible</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualitza</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Ha fallat la baixada del contingut %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Ha acabat la baixada</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tipus desconegut d&apos;eina %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Afegeix un element</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tots els acceptats (%1)</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tipus desconegut de contingut %1</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Elimina la pàgina %1 del document</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>La pàgina %1 ha estat eliminada</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Ha fallat l&apos;operació d&apos;afegir un fitxer: error en copiar el fitxer</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Agrupa</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Desagrupa</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Color</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>No s&apos;ha pogut afegir la imatge a la llibreria</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>CapturedImage</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Propietats de la memòria cau</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Mida:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Captura part de la pantalla</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Captura la pantalla</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Mostra la barra d&apos;estris</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Mostra el tauler a la pantalla secundària</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Mostra l&apos;escriptori a la pantalla secundària</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Carpeta nova</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Pàgina %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Afegeix una carpeta d&apos;imatges</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Afegeix imatges</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Afegeix pàgines des d&apos;un fitxer</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>S&apos;està duplicant el document %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>S&apos;ha copiat el document %1</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Suprimeix la pàgina</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Suprimeix el document</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Esteu segur que voleu eliminar el document &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Buida la paperera</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Esteu segur que voleu buidar la paperera?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">S&apos;està buidant la paperera</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">S&apos;ha buidat la paperera</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Suprimeix la carpeta</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Esteu segur que voleu suprimir la carpeta &apos;%1&apos; i tot el seu contingut?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">No hi ha cap document seleccionat!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Obre un fitxer acceptat</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>S&apos;està important el fitxer %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Ha fallat la importació del fitxer...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importa totes les imatges de la carpeta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Buida</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Obre un document</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Afegeix totes les imatges al document</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Totes les imatges (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>La selecció no conté cap fitxer d&apos;imatge!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Esteu segur que voleu eliminar %n pàgina del document seleccionat &apos;%1&apos;?</numerusform>
            <numerusform>Esteu segur que voleu eliminar %n pàgines del document seleccionat &apos;%1&apos;?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>La carpeta no conté cap fitxer d&apos;imatge</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documents sense títol</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished">¿Está seguro de que desexa eliminar els elements seleccionats?</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>imatges</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>vídeos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objectes</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>ginys</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Tots els fitxers acceptats (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>S&apos;ha desat el fitxer %1</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>S&apos;està inserint la pàgina %1 de %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>La importació ha estat correcta.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>La importació del fitxer %1 ha estat correcta.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>S&apos;està important el fitxer %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Pàgina %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">L&apos;exportació ha fallat.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel·la</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 pàgina copiada</numerusform>
            <numerusform>%1 pàgines copiades</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 pàgina copiada</numerusform>
            <numerusform>%1 pàgines copiades</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>¿Está seguro de que desexa eliminar els elements seleccionats?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">S&apos;està copiant la pàgina %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (còpia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">S&apos;està copiant la pàgina %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 pàgina copiada</numerusform>
            <numerusform>%1 pàgines copiades</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>S&apos;estan baixant fitxers</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pàgina %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pàgina %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Advertiments: durant l&apos;exportació han aparegut</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exporta a IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exporta com a fitxer IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>L&apos;exportació ha fallat.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exporta com a fitxer UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>S&apos;està exportant %1 %2 de %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">L&apos;exportació ha fallat.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporta com a fitxer PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporta a PDF</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">L&apos;exportació ha estat correcta.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporta com a fitxer PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>S&apos;està exportant la pàgina %1 de %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporta a PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exporta com a dades web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>S&apos;està exportant el document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>L&apos;exportació ha estat correcta.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>L&apos;exportació ha fallat.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exporta al navegador web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Afegeix a la pàgina</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Estableix com a fons</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Afegeix a la biblioteca</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informacions de l&apos;objecte</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Afegeix als llocs d&apos;interès</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Comparteix</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Torna a explorar el sistema de fitxers</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Torna a la carpeta</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Elimina dels llocs d&apos;interès</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Crea una carpeta nova</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Imatge importada</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Sons</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animacions</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interactivitats</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplicacions</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formes</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferits</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Cerca a la web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Paperera</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Escriviu el nom de la carpeta nova</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>S&apos;està carregant </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Blocat</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible a la pantalla estesa</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Blocat</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible a la pantalla estesa</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Ves a la font de contingut</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Estableix com a fons</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Escriu text aquí&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Color del text</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editable</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>S&apos;està carregant ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Congelat</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transforma en eina</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Format de fitxer comú (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>S&apos;està important el fitxer %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Ha fallat la importació del fitxer %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>La importació ha estat correcta.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Ha fallat la importació.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>S&apos;està important el fitxer %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>La importació ha estat correcta.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Ha fallat la importació del fitxer %1.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Format d&apos;imatge (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Format de document portable (*.PDF)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Ha fallat la importació del PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>S&apos;està important la pàgina %1 de %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Ha ocorregut un error mentre es publicava el vídeo a la intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>La publicació a la intranet està en progrés %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publica</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Entra</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Escriviu el nom d&apos;usuari i la contrasenya per a &quot;%1&quot; a %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Ha fallat el registre al servidor intermediari</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Errors d&apos;SSL: 

%1

%2

Voleu ignorar aquests errors per a aquest amfitrió?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel·la</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(còpia)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Pèrdua del repositori de documents</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Anglès</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Rus</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemany</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francès</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francès de Suïssa</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>No s&apos;ha pogut iniciar el codificador...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>No hi ha disponible el codificador de podcast...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Part %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>al vostre escriptori ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>a la carpeta %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>S&apos;ha creat el podcast %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>S&apos;ha produït un error en enregistrar el podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Entrada d&apos;àudio per defecte</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>No hi ha enregistraments d&apos;àudio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publica a la intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publica a YouTube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versió:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>El marcador és sensible a la pressió</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Inici de sessió al servidor intermediari</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Contrasenya:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publica el document a la web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Títol:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descripció:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publica</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Les meves pel·lícules</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>S&apos;estan generant les miniatures de previsualització...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>S&apos;han generat %1 miniatures...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pàgina %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Compass</source>
        <translation>Compàs</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Regle</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Transportador</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation>Màscara</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Escaire</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Memòria cau</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Pàgina sencera</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Actualitzador de documents</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> fitxers requereixen una actualització.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Ubicació de la còpia de seguretat: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navega</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Seleccioneu una carpeta per a les còpies de seguretat</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>L&apos;actualització dels fitxers ha estat correcta.
Reinicieu l&apos;aplicació per accedir als documents actualitzats.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Ha ocorregut un error durant l&apos;actualització. Els fitxers no s&apos;han vist afectats.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultats de l&apos;actualització de fitxers</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>S&apos;està actualitzant un fitxer </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Espereu, el procés d&apos;importació començarà aviat...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recorda-m&apos;ho després</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>S&apos;està carregant...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 cridats (mètode=%1, estat=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Ha fallat l&apos;autenticació al YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Ha ocorregut un error mentre es carregava el vídeo al YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>La càrrega al YouTube és en progrés %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Automòbils i vehicles</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Animals i mascotes</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Esports</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Viatges i esdeveniments</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Jocs</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comèdia</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Gent i blocs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Notícies i política</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Entreteniment</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Educació</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Consells i estil</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>ONG i activisme</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Ciència i tecnologia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Neteja</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>S&apos;ha cancel·lat la baixada: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Ha ocorregut un error quan s&apos;obria el fitxer desat: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Ha ocorregut un error mentre es desava: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Error de xarxa: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segons</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuts</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 restants</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 de %2 (%3/segon) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Aturat</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 baixades</translation>
    </message>
    <message>
        <source>1 Download</source>
        <translation>1 baixada</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 elements</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Pes&amp;tanya nova</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Clona la pestanya</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Tan&amp;ca la pestanya</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Tanca &amp;altres pestanyes</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recarrega la pestanya</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recarrega totes les pestanyes</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Pestanyes tancades recentment</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Sense títol)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>No hi ha cap cerca recent</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Cerques recents</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Neteja les cerques recents</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Afegeix al document actual</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>S&apos;ha produït un error en carregar la pàgina: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Obre en una pestanya nova</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publica un podcast al YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Paraules clau</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Usuari del YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Contrasenya del YouTube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Clicant &apos;Carrega,&apos; certifiqueu que teniu tots els drets sobre el contingut o que esteu autoritzats pel propietari dels drets a fer-lo públicament disponible al YouTube, així com que el contingut compleix amb els termes de servei del YouTube localitzats a &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>Opacitat</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Sobre fons clar</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sobre fons fosc</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Amplada de la línia</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Ressaltat</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fi</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>El llapis és sensible a la pressió</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Adreça de correu electrònic</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor/a</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Diàleg</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Títol</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">Adreça de correu electrònic</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor/a</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Descripció</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versió: …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Paràmetres per defecte</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Mostra la pàgina amb un navegador extern</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pàgina d&apos;inici:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclat virtual</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Mida de les tecles:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Col·locada a la part superior (recomanat per a les tauletes)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Col·locada a la part inferior (recomanat per a les pissarres)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Mostra el text sota el botó</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Barra d&apos;estris</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horitzontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígraf</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Actualització del programari</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Comprova si hi ha actualitzacions del programari en engegar</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Llicències</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Mostra el contingut de la pàgina web en un monitor o projector secundari</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Pantalla múltiple</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Canvia entre &apos;control de la pantalla&apos; i &apos;visualització de la pantalla&apos;</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalitat</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Comença en la modalitat:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tauler</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Nom d&apos;usuari del servidor intermediari:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Crèdits</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Sobre fons fosc</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Opacitat</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Sobre fons clar</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Captura d&apos;un objecte Flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Seleccioneu l&apos;objecte Flash a capturar</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nom de l&apos;aplicació</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Crea una aplicació</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
